==> haskell-conduit-parse-0.2.1.1-211-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit-parse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 conduit-parse
version:              0.2.1.1
visibility:           public
id:                   conduit-parse-0.2.1.1-2Gsr9cYoJVJHStTJKSaXwJ
key:                  conduit-parse-0.2.1.1-2Gsr9cYoJVJHStTJKSaXwJ
license:              LicenseRef-PublicDomain
maintainer:           koral <koral@mailoo.org>
author:               koral <koral@mailoo.org>
homepage:             https://github.com/k0ral/conduit-parse
synopsis:             Parsing framework based on conduit.
description:          Please refer to README.
category:             Conduit, Text
abi:                  b0a7a76424ebb9181eaca1cb48566df7
exposed:              True
exposed-modules:      Data.Conduit.Parser
hidden-modules:       Data.Conduit.Parser.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/conduit-parse-0.2.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/conduit-parse-0.2.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/conduit-parse-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-conduit-parse
hs-libraries:         HSconduit-parse-0.2.1.1-2Gsr9cYoJVJHStTJKSaXwJ
depends:
    base-4.17.2.1 conduit-1.3.6.1-KsdSqMrhyj62FrKu923JJM
    dlist-1.0-I6FB5Nlk17hG16fxQzZSEb mtl-2.2.2
    parsers-0.12.12-Gg30xYDgWIsLUaRmDLfQS0
    safe-0.3.21-Lt2Z3SBSCxg5kPCeY0ZLHQ
    safe-exceptions-0.1.7.4-9wzBY0Llz9vFn4SsuxIYLD text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-conduit-parse/html/conduit-parse.haddock

haddock-html:         /usr/share/doc/haskell-conduit-parse/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-parse-0.2.1.1-212-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-conduit-parse.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 conduit-parse
version:              0.2.1.1
visibility:           public
id:                   conduit-parse-0.2.1.1-FN2zJJ5FMtR5u9MlftvmtO
key:                  conduit-parse-0.2.1.1-FN2zJJ5FMtR5u9MlftvmtO
license:              LicenseRef-PublicDomain
maintainer:           koral <koral@mailoo.org>
author:               koral <koral@mailoo.org>
homepage:             https://github.com/k0ral/conduit-parse
synopsis:             Parsing framework based on conduit.
description:          Please refer to README.
category:             Conduit, Text
abi:                  ce2b6466e18ec05622b7cf6e57b2d55a
exposed:              True
exposed-modules:      Data.Conduit.Parser
hidden-modules:       Data.Conduit.Parser.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/conduit-parse-0.2.1.1
library-dirs:         /usr/lib/ghc-9.4.8/site-local/conduit-parse-0.2.1.1
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/conduit-parse-0.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-conduit-parse
hs-libraries:         HSconduit-parse-0.2.1.1-FN2zJJ5FMtR5u9MlftvmtO
depends:
    base-4.17.2.1 conduit-1.3.6.1-8OSOdkGtcaZ23KS6p4zYxn
    dlist-1.0-I6FB5Nlk17hG16fxQzZSEb mtl-2.2.2
    parsers-0.12.12-AhFSziNPdIpAN1hriGUYjg
    safe-0.3.21-Kon8H9MPMa4IsQ5S7RcDtP
    safe-exceptions-0.1.7.4-ENx9aLlHfdwFBxAvSy0snM text-2.0.2
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-conduit-parse/html/conduit-parse.haddock

haddock-html:         /usr/share/doc/haskell-conduit-parse/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
